@@ -3,5 +3,6 @@ from .data import getdata  # noqa: F401
 from .__utils__ import filesize, desc  # noqa: F401
 from .__about__ import __version__  # noqa: F401
 from .blob_storage import blob_storage # noqa F401
-from .sim import normal, bernoulli, poisson, discrete, Dist, dag
+from .dist import normal, bernoulli, poisson, discrete, Dist
+from .dag import dag
 from .reload import reload  # noqa F401
